@@ -15,23 +15,21 @@
 #
 # @author: Shubhangi Satras, Cisco Systems, Inc.
 #          Shweta Padubidri, Cisco Systems, Inc.
-#
+
+import logging
 import unittest
-import logging as LOG
+
 from quantum.common import exceptions as exc
 from quantum.plugins.cisco.common import cisco_constants as const
-from quantum.plugins.cisco.ucs import cisco_ucs_plugin
-from quantum.plugins.cisco.ucs import cisco_ucs_configuration  as conf
 from quantum.plugins.cisco.common import cisco_credentials as cred
-
+from quantum.plugins.cisco.common import cisco_exceptions as c_exc
 from quantum.plugins.cisco.db import api as db
 from quantum.plugins.cisco.db import l2network_db as cdb
-from quantum.plugins.cisco.common import cisco_exceptions as c_exc
-
+from quantum.plugins.cisco.ucs import cisco_ucs_configuration as conf
 from quantum.plugins.cisco.ucs import cisco_ucs_inventory as ucsinv
+from quantum.plugins.cisco.ucs import cisco_ucs_plugin
 
-LOG.basicConfig(level=LOG.WARN)
-LOG.getLogger("cisco_ucs_plugin")
+LOG = logging.getLogger(__name__)
 
 
 class UCSVICTestPlugin(unittest.TestCase):
@@ -53,13 +51,13 @@ class UCSVICTestPlugin(unittest.TestCase):
         self.device_ip = conf.UCSM_IP_ADDRESS
         self._ucs_inventory = ucsinv.UCSInventory()
         self._ucs_inventory._load_inventory()
-        self.chassis_id_list = self._ucs_inventory._inventory[\
-                               self.device_ip].keys()
+        self.chassis_id_list = (
+            self._ucs_inventory._inventory[self.device_ip].keys())
         self.chassis_id = self.chassis_id_list[0]
-        self.blade_id_list = self._ucs_inventory._inventory[\
-                             self.device_ip][self.chassis_id]
-        self.blade_id = self._ucs_inventory._inventory[\
-                             self.device_ip][self.chassis_id][0]
+        self.blade_id_list = (
+            self._ucs_inventory._inventory[self.device_ip][self.chassis_id])
+        self.blade_id = (
+            self._ucs_inventory._inventory[self.device_ip][self.chassis_id][0])
 
     def test_create_network(self):
         """
@@ -70,9 +68,9 @@ class UCSVICTestPlugin(unittest.TestCase):
         cdb.add_vlan_binding(str(self.vlan_id), self.vlan_name,
                              new_network[const.UUID])
         new_net_dict = self._cisco_ucs_plugin.create_network(
-                self.tenant_id, new_network[const.NETWORKNAME],
-                new_network[const.UUID], self.vlan_name, self.vlan_id,
-                device_ip=self.device_ip)
+            self.tenant_id, new_network[const.NETWORKNAME],
+            new_network[const.UUID], self.vlan_name, self.vlan_id,
+            device_ip=self.device_ip)
         self.assertEqual(new_net_dict[const.NET_ID], new_network[const.UUID])
         self.assertEqual(new_net_dict[const.NET_NAME],
                          new_network[const.NETWORKNAME])
@@ -88,11 +86,11 @@ class UCSVICTestPlugin(unittest.TestCase):
         cdb.add_vlan_binding(str(self.vlan_id), self.vlan_name,
                              new_network[const.UUID])
         new_net_dict = self._cisco_ucs_plugin.create_network(
-                self.tenant_id, new_network[const.NETWORKNAME],
-                new_network[const.UUID], self.vlan_name, self.vlan_id,
-                device_ip=self.device_ip)
+            self.tenant_id, new_network[const.NETWORKNAME],
+            new_network[const.UUID], self.vlan_name, self.vlan_id,
+            device_ip=self.device_ip)
         new_net_dict = self._cisco_ucs_plugin.delete_network(
-           self.tenant_id, new_network[const.UUID], device_ip=self.device_ip)
+            self.tenant_id, new_network[const.UUID], device_ip=self.device_ip)
         self.assertEqual(new_net_dict[const.NET_ID], new_network[const.UUID])
 
     def test_get_network_details(self):
@@ -105,12 +103,12 @@ class UCSVICTestPlugin(unittest.TestCase):
         cdb.add_vlan_binding(str(self.vlan_id), self.vlan_name,
                              new_network[const.UUID])
         new_net_dict = self._cisco_ucs_plugin.create_network(
-                self.tenant_id, new_network[const.NETWORKNAME],
-                new_network[const.UUID], self.vlan_name, self.vlan_id,
-                device_ip=self.device_ip)
+            self.tenant_id, new_network[const.NETWORKNAME],
+            new_network[const.UUID], self.vlan_name, self.vlan_id,
+            device_ip=self.device_ip)
         new_net_dict = self._cisco_ucs_plugin.get_network_details(
-                   self.tenant_id, new_network[const.UUID],
-                   device_ip=self.device_ip)
+            self.tenant_id, new_network[const.UUID],
+            device_ip=self.device_ip)
         self.assertEqual(new_net_dict[const.NET_ID], new_network[const.UUID])
         self.assertEqual(new_net_dict[const.NET_NAME],
                          new_network[const.NETWORKNAME])
@@ -127,18 +125,18 @@ class UCSVICTestPlugin(unittest.TestCase):
         cdb.add_vlan_binding(str(self.vlan_id), self.vlan_name,
                              new_network1[const.UUID])
         new_net_dict1 = self._cisco_ucs_plugin.create_network(
-                self.tenant_id, new_network1[const.NETWORKNAME],
-                new_network1[const.UUID], self.vlan_name, self.vlan_id,
-                device_ip=self.device_ip)
+            self.tenant_id, new_network1[const.NETWORKNAME],
+            new_network1[const.UUID], self.vlan_name, self.vlan_id,
+            device_ip=self.device_ip)
         new_network2 = db.network_create(self.tenant_id, "test_network2")
         cdb.add_vlan_binding("6", "q-000006vlan", new_network2[const.UUID])
         new_net_dict2 = self._cisco_ucs_plugin.create_network(
-                self.tenant_id, new_network2[const.NETWORKNAME],
-                new_network2[const.UUID], "q-000006vlan", "6",
-                device_ip=self.device_ip)
+            self.tenant_id, new_network2[const.NETWORKNAME],
+            new_network2[const.UUID], "q-000006vlan", "6",
+            device_ip=self.device_ip)
 
         net_list = self._cisco_ucs_plugin.get_all_networks(
-                                self.tenant_id, device_ip=self.device_ip)
+            self.tenant_id, device_ip=self.device_ip)
         net_id_list = [new_net_dict1, new_net_dict2]
 
         self.assertTrue(net_list[0] in net_id_list)
@@ -156,29 +154,29 @@ class UCSVICTestPlugin(unittest.TestCase):
         cdb.add_vlan_binding(str(self.vlan_id), self.vlan_name,
                              new_network[const.UUID])
         new_net_dict = self._cisco_ucs_plugin.create_network(
-                self.tenant_id, new_network[const.NETWORKNAME],
-                new_network[const.UUID], self.vlan_name, self.vlan_id,
-                device_ip=self.device_ip)
+            self.tenant_id, new_network[const.NETWORKNAME],
+            new_network[const.UUID], self.vlan_name, self.vlan_id,
+            device_ip=self.device_ip)
         new_port1 = db.port_create(new_network[const.UUID], const.PORT_UP)
         port_dict1 = self._cisco_ucs_plugin.create_port(
-                            self.tenant_id, self.net_id, const.PORT_UP,
-                            new_port1[const.UUID], device_ip=self.device_ip,
-                            ucs_inventory=self._ucs_inventory,
-                            least_rsvd_blade_dict=self._ucs_inventory.\
-                            _get_least_reserved_blade())
+            self.tenant_id, self.net_id, const.PORT_UP,
+            new_port1[const.UUID], device_ip=self.device_ip,
+            ucs_inventory=self._ucs_inventory,
+            least_rsvd_blade_dict=(
+                self._ucs_inventory._get_least_reserved_blade()))
         new_port2 = db.port_create(new_network[const.UUID], const.PORT_UP)
         port_dict2 = self._cisco_ucs_plugin.create_port(
-                               self.tenant_id, self.net_id, const.PORT_UP,
-                               new_port2[const.UUID], device_ip=self.device_ip,
-                               ucs_inventory=self._ucs_inventory,
-                               least_rsvd_blade_dict=self._ucs_inventory.\
-                               _get_least_reserved_blade())
+            self.tenant_id, self.net_id, const.PORT_UP,
+            new_port2[const.UUID], device_ip=self.device_ip,
+            ucs_inventory=self._ucs_inventory,
+            least_rsvd_blade_dict=(
+                self._ucs_inventory._get_least_reserved_blade()))
         ports_on_net = self._cisco_ucs_plugin.get_all_ports(
-                           self.tenant_id, new_net_dict[const.NET_ID],
-                           device_ip=self.device_ip,
-                           ucs_inventory=self._ucs_inventory,
-                           least_rsvd_blade_dict=self._ucs_inventory.\
-                           _get_least_reserved_blade())
+            self.tenant_id, new_net_dict[const.NET_ID],
+            device_ip=self.device_ip,
+            ucs_inventory=self._ucs_inventory,
+            least_rsvd_blade_dict=(
+                self._ucs_inventory._get_least_reserved_blade()))
         port_list = [port_dict1, port_dict2]
         self.assertTrue(str(ports_on_net[1]) == str(port_list[1]) or
                         str(ports_on_net[1]) == str(port_list[0]))
@@ -186,19 +184,19 @@ class UCSVICTestPlugin(unittest.TestCase):
                         str(ports_on_net[0]) == str(port_list[0]))
 
         blade_intf_details = self._ucs_inventory._get_rsvd_blade_intf_by_port(
-                                      self.tenant_id, port_dict1[const.PORTID])
+            self.tenant_id, port_dict1[const.PORTID])
         self._cisco_ucs_plugin.delete_port(
-                     self.tenant_id, new_net_dict[const.NET_ID],
-                     port_dict1[const.PORTID], device_ip=self.device_ip,
-                     ucs_inventory=self._ucs_inventory,
-                     chassis_id=self.chassis_id, blade_id=self.blade_id,
-                     blade_intf_distinguished_name=blade_intf_details[\
-                     const.BLADE_INTF_DN],
-                     least_rsvd_blade_dict=self._ucs_inventory.\
-                     _get_least_reserved_blade())
+            self.tenant_id, new_net_dict[const.NET_ID],
+            port_dict1[const.PORTID], device_ip=self.device_ip,
+            ucs_inventory=self._ucs_inventory,
+            chassis_id=self.chassis_id, blade_id=self.blade_id,
+            blade_intf_distinguished_name=blade_intf_details[
+                const.BLADE_INTF_DN],
+            least_rsvd_blade_dict=(
+                self._ucs_inventory._get_least_reserved_blade()))
         self.tear_down_network_port(
-                 self.tenant_id, new_net_dict[const.NET_ID],
-                 port_dict2[const.PORTID])
+            self.tenant_id, new_net_dict[const.NET_ID],
+            port_dict2[const.PORTID])
 
     def test_create_port(self):
         """
@@ -210,23 +208,23 @@ class UCSVICTestPlugin(unittest.TestCase):
         cdb.add_vlan_binding(str(self.vlan_id), self.vlan_name,
                              new_network[const.UUID])
         new_net_dict = self._cisco_ucs_plugin.create_network(
-                self.tenant_id, new_network[const.NETWORKNAME],
-                new_network[const.UUID], self.vlan_name, self.vlan_id,
-                device_ip=self.device_ip)
+            self.tenant_id, new_network[const.NETWORKNAME],
+            new_network[const.UUID], self.vlan_name, self.vlan_id,
+            device_ip=self.device_ip)
         new_port = db.port_create(new_network[const.UUID], const.PORT_UP)
         port_dict = self._cisco_ucs_plugin.create_port(
-                            self.tenant_id, self.net_id, const.PORT_UP,
-                            new_port[const.UUID], device_ip=self.device_ip,
-                            ucs_inventory=self._ucs_inventory,
-                            least_rsvd_blade_dict=self._ucs_inventory.\
-                            _get_least_reserved_blade())
+            self.tenant_id, self.net_id, const.PORT_UP,
+            new_port[const.UUID], device_ip=self.device_ip,
+            ucs_inventory=self._ucs_inventory,
+            least_rsvd_blade_dict=(
+                self._ucs_inventory._get_least_reserved_blade()))
         self.assertEqual(port_dict[const.PORTID], new_port[const.UUID])
-        profile_name = self._cisco_ucs_plugin.\
-                           _get_profile_name(port_dict[const.PORTID])
+        profile_name = (
+            self._cisco_ucs_plugin._get_profile_name(port_dict[const.PORTID]))
         self.assertTrue(profile_name is not None)
         self.tear_down_network_port(
-                 self.tenant_id, new_net_dict[const.NET_ID],
-                 port_dict[const.PORTID])
+            self.tenant_id, new_net_dict[const.NET_ID],
+            port_dict[const.PORTID])
 
     def test_delete_port(self):
         """
@@ -240,28 +238,28 @@ class UCSVICTestPlugin(unittest.TestCase):
         cdb.add_vlan_binding(str(self.vlan_id), self.vlan_name,
                              new_network[const.UUID])
         new_net_dict = self._cisco_ucs_plugin.create_network(
-                self.tenant_id, new_network[const.NETWORKNAME],
-                new_network[const.UUID], self.vlan_name, self.vlan_id,
-                device_ip=self.device_ip)
+            self.tenant_id, new_network[const.NETWORKNAME],
+            new_network[const.UUID], self.vlan_name, self.vlan_id,
+            device_ip=self.device_ip)
         new_port = db.port_create(new_network[const.UUID], const.PORT_UP)
         port_dict = self._cisco_ucs_plugin.create_port(
-                            self.tenant_id, self.net_id, const.PORT_UP,
-                            new_port[const.UUID], device_ip=self.device_ip,
-                            ucs_inventory=self._ucs_inventory,
-                            least_rsvd_blade_dict=self._ucs_inventory.\
-                            _get_least_reserved_blade())
+            self.tenant_id, self.net_id, const.PORT_UP,
+            new_port[const.UUID], device_ip=self.device_ip,
+            ucs_inventory=self._ucs_inventory,
+            least_rsvd_blade_dict=(
+                self._ucs_inventory._get_least_reserved_blade()))
 
         blade_intf_details = self._ucs_inventory._get_rsvd_blade_intf_by_port(
-                                       self.tenant_id, port_dict[const.PORTID])
+            self.tenant_id, port_dict[const.PORTID])
         port_bind = self._cisco_ucs_plugin.delete_port(
-                         self.tenant_id, new_net_dict[const.NET_ID],
-                         port_dict[const.PORTID], device_ip=self.device_ip,
-                         ucs_inventory=self._ucs_inventory,
-                         chassis_id=self.chassis_id, blade_id=self.blade_id,
-                         blade_intf_distinguished_name=blade_intf_details[\
-                         const.BLADE_INTF_DN],
-                         least_rsvd_blade_dict=self._ucs_inventory.\
-                         _get_least_reserved_blade())
+            self.tenant_id, new_net_dict[const.NET_ID],
+            port_dict[const.PORTID], device_ip=self.device_ip,
+            ucs_inventory=self._ucs_inventory,
+            chassis_id=self.chassis_id, blade_id=self.blade_id,
+            blade_intf_distinguished_name=blade_intf_details[
+                const.BLADE_INTF_DN],
+            least_rsvd_blade_dict=(
+                self._ucs_inventory._get_least_reserved_blade()))
 
         self.assertEqual(port_bind[const.PORTID], new_port[const.UUID])
         self.tear_down_network(self.tenant_id, new_net_dict[const.NET_ID])
@@ -276,24 +274,24 @@ class UCSVICTestPlugin(unittest.TestCase):
         cdb.add_vlan_binding(str(self.vlan_id), self.vlan_name,
                              new_network[const.UUID])
         new_net_dict = self._cisco_ucs_plugin.create_network(
-                self.tenant_id, new_network[const.NETWORKNAME],
-                new_network[const.UUID], self.vlan_name, self.vlan_id,
-                device_ip=self.device_ip)
+            self.tenant_id, new_network[const.NETWORKNAME],
+            new_network[const.UUID], self.vlan_name, self.vlan_id,
+            device_ip=self.device_ip)
         new_port = db.port_create(new_network[const.UUID], port_state)
         port_dict = self._cisco_ucs_plugin.create_port(
-                            self.tenant_id, self.net_id, port_state,
-                            new_port[const.UUID], device_ip=self.device_ip,
-                            ucs_inventory=self._ucs_inventory,
-                            least_rsvd_blade_dict=self._ucs_inventory.\
-                            _get_least_reserved_blade())
+            self.tenant_id, self.net_id, port_state,
+            new_port[const.UUID], device_ip=self.device_ip,
+            ucs_inventory=self._ucs_inventory,
+            least_rsvd_blade_dict=(
+                self._ucs_inventory._get_least_reserved_blade()))
 
         port_detail = self._cisco_ucs_plugin.get_port_details(
-                            self.tenant_id, new_net_dict[const.NET_ID],
-                            port_dict[const.PORTID], device_ip=self.device_ip)
+            self.tenant_id, new_net_dict[const.NET_ID],
+            port_dict[const.PORTID], device_ip=self.device_ip)
         self.assertEqual(str(port_dict), str(port_detail))
         self.tear_down_network_port(
-                 self.tenant_id, new_net_dict[const.NET_ID],
-                 port_dict[const.PORTID])
+            self.tenant_id, new_net_dict[const.NET_ID],
+            port_dict[const.PORTID])
 
     def test_get_port_details_state_up(self):
         """
@@ -318,11 +316,11 @@ class UCSVICTestPlugin(unittest.TestCase):
         new_port = db.port_create(new_network[const.UUID], const.PORT_UP)
         self._cisco_ucs_plugin._set_ucsm(self.device_ip)
         new_port_profile = self._cisco_ucs_plugin._create_port_profile(
-                                self.tenant_id, new_network[const.UUID],
-                                new_port[const.UUID], self.vlan_name,
-                                self.vlan_id)
-        profile_name = self._cisco_ucs_plugin.\
-                            _get_profile_name(new_port[const.UUID])
+            self.tenant_id, new_network[const.UUID],
+            new_port[const.UUID], self.vlan_name,
+            self.vlan_id)
+        profile_name = (
+            self._cisco_ucs_plugin._get_profile_name(new_port[const.UUID]))
         self.assertEqual(new_port_profile[const.PROFILE_NAME], profile_name)
         self.assertEqual(new_port_profile[const.PROFILE_VLAN_NAME],
                          self.vlan_name)
@@ -341,11 +339,11 @@ class UCSVICTestPlugin(unittest.TestCase):
         new_port = db.port_create(new_network[const.UUID], const.PORT_UP)
         self._cisco_ucs_plugin._set_ucsm(self.device_ip)
         self._cisco_ucs_plugin._create_port_profile(
-                                self.tenant_id, new_network[const.UUID],
-                                new_port[const.UUID], self.vlan_name,
-                                self.vlan_id)
-        profile_name = self._cisco_ucs_plugin.\
-                            _get_profile_name(new_port[const.UUID])
+            self.tenant_id, new_network[const.UUID],
+            new_port[const.UUID], self.vlan_name,
+            self.vlan_id)
+        profile_name = (
+            self._cisco_ucs_plugin._get_profile_name(new_port[const.UUID]))
 
         counter1 = self._cisco_ucs_plugin._port_profile_counter
         self._cisco_ucs_plugin._delete_port_profile(new_port[const.UUID],
@@ -364,28 +362,28 @@ class UCSVICTestPlugin(unittest.TestCase):
         cdb.add_vlan_binding(str(self.vlan_id), self.vlan_name,
                              new_network[const.UUID])
         new_net_dict = self._cisco_ucs_plugin.create_network(
-                self.tenant_id, new_network[const.NETWORKNAME],
-                new_network[const.UUID], self.vlan_name, self.vlan_id,
-                device_ip=self.device_ip)
+            self.tenant_id, new_network[const.NETWORKNAME],
+            new_network[const.UUID], self.vlan_name, self.vlan_id,
+            device_ip=self.device_ip)
         new_port = db.port_create(new_network[const.UUID], const.PORT_UP)
         port_dict = self._cisco_ucs_plugin.create_port(
-                            self.tenant_id, new_net_dict[const.NET_ID],
-                            const.PORT_UP, new_port[const.UUID],
-                            device_ip=self.device_ip,
-                            ucs_inventory=self._ucs_inventory,
-                            least_rsvd_blade_dict=self._ucs_inventory.\
-                            _get_least_reserved_blade())
+            self.tenant_id, new_net_dict[const.NET_ID],
+            const.PORT_UP, new_port[const.UUID],
+            device_ip=self.device_ip,
+            ucs_inventory=self._ucs_inventory,
+            least_rsvd_blade_dict=(
+                self._ucs_inventory._get_least_reserved_blade()))
         cdb.update_vlan_binding(new_network[const.UUID],
                                 str(new_vlanid), new_vlan_name)
         port_bind = self._cisco_ucs_plugin.plug_interface(
-                           self.tenant_id, new_net_dict[const.NET_ID],
-                           port_dict[const.PORTID], remote_interface_id,
-                           device_ip=self.device_ip)
+            self.tenant_id, new_net_dict[const.NET_ID],
+            port_dict[const.PORTID], remote_interface_id,
+            device_ip=self.device_ip)
         self.assertEqual(port_bind[const.VLANNAME], new_vlan_name)
         self.assertEqual(port_bind[const.VLANID], new_vlanid)
         self.tear_down_network_port_interface(
-                                   self.tenant_id, new_net_dict[const.NET_ID],
-                                   new_port[const.UUID])
+            self.tenant_id, new_net_dict[const.NET_ID],
+            new_port[const.UUID])
 
     def test_unplug_interface(self, remote_interface_id=None,
                               new_vlanid=10, new_vlan_name='new_vlan'):
@@ -398,32 +396,32 @@ class UCSVICTestPlugin(unittest.TestCase):
         cdb.add_vlan_binding(str(self.vlan_id), self.vlan_name,
                              new_network[const.UUID])
         new_net_dict = self._cisco_ucs_plugin.create_network(
-                self.tenant_id, new_network[const.NETWORKNAME],
-                new_network[const.UUID], self.vlan_name, self.vlan_id,
-                device_ip=self.device_ip)
+            self.tenant_id, new_network[const.NETWORKNAME],
+            new_network[const.UUID], self.vlan_name, self.vlan_id,
+            device_ip=self.device_ip)
         new_port = db.port_create(new_network[const.UUID], const.PORT_UP)
         port_dict = self._cisco_ucs_plugin.create_port(
-                            self.tenant_id, new_net_dict[const.NET_ID],
-                            const.PORT_UP, new_port[const.UUID],
-                            device_ip=self.device_ip,
-                            ucs_inventory=self._ucs_inventory,
-                            least_rsvd_blade_dict=self._ucs_inventory.\
-                            _get_least_reserved_blade())
+            self.tenant_id, new_net_dict[const.NET_ID],
+            const.PORT_UP, new_port[const.UUID],
+            device_ip=self.device_ip,
+            ucs_inventory=self._ucs_inventory,
+            least_rsvd_blade_dict=(
+                self._ucs_inventory._get_least_reserved_blade()))
         cdb.update_vlan_binding(new_network[const.UUID],
                                 str(new_vlanid), new_vlan_name)
         self._cisco_ucs_plugin.plug_interface(
-                           self.tenant_id, new_net_dict[const.NET_ID],
-                           port_dict[const.PORTID], remote_interface_id,
-                           device_ip=self.device_ip)
+            self.tenant_id, new_net_dict[const.NET_ID],
+            port_dict[const.PORTID], remote_interface_id,
+            device_ip=self.device_ip)
 
         port_bind = self._cisco_ucs_plugin.unplug_interface(
-                           self.tenant_id, new_net_dict[const.NET_ID],
-                           port_dict[const.PORTID], device_ip=self.device_ip)
+            self.tenant_id, new_net_dict[const.NET_ID],
+            port_dict[const.PORTID], device_ip=self.device_ip)
         self.assertEqual(port_bind[const.VLANNAME], self.vlan_name)
         self.assertEqual(port_bind[const.VLANID], self.vlan_id)
         self.tear_down_network_port_interface(
-                                   self.tenant_id, new_net_dict[const.NET_ID],
-                                   new_port[const.UUID])
+            self.tenant_id, new_net_dict[const.NET_ID],
+            new_port[const.UUID])
 
     def test_get_vlan_name_for_network(self):
         """
@@ -434,7 +432,7 @@ class UCSVICTestPlugin(unittest.TestCase):
         cdb.add_vlan_binding(str(self.vlan_id), self.vlan_name,
                              new_network[const.UUID])
         vlan_bind_name = self._cisco_ucs_plugin._get_vlan_name_for_network(
-                                    self.tenant_id, new_network[const.UUID])
+            self.tenant_id, new_network[const.UUID])
 
         self.assertEqual(vlan_bind_name, self.vlan_name)
 
@@ -447,7 +445,7 @@ class UCSVICTestPlugin(unittest.TestCase):
         cdb.add_vlan_binding(str(self.vlan_id), self.vlan_name,
                              new_network[const.UUID])
         vlan_bind_id = self._cisco_ucs_plugin._get_vlan_id_for_network(
-                                    self.tenant_id, new_network[const.UUID])
+            self.tenant_id, new_network[const.UUID])
         self.assertEqual(str(vlan_bind_id), self.vlan_id)
 
     def test_show_network_not_found(self):
@@ -476,9 +474,9 @@ class UCSVICTestPlugin(unittest.TestCase):
         cdb.add_vlan_binding(str(self.vlan_id), self.vlan_name,
                              new_network[const.UUID])
         new_net_dict = self._cisco_ucs_plugin.create_network(
-                self.tenant_id, new_network[const.NETWORKNAME],
-                new_network[const.UUID], self.vlan_name, self.vlan_id,
-                device_ip=self.device_ip)
+            self.tenant_id, new_network[const.NETWORKNAME],
+            new_network[const.UUID], self.vlan_name, self.vlan_id,
+            device_ip=self.device_ip)
 
         self.assertRaises(c_exc.PortVnicNotFound,
                           self._cisco_ucs_plugin.delete_port,
@@ -487,8 +485,8 @@ class UCSVICTestPlugin(unittest.TestCase):
                           ucs_inventory=self._ucs_inventory,
                           chassis_id=self.chassis_id, blade_id=self.blade_id,
                           blade_intf_distinguished_name=None,
-                          least_rsvd_blade_dict=self._ucs_inventory.\
-                          _get_least_reserved_blade())
+                          least_rsvd_blade_dict=(
+                              self._ucs_inventory._get_least_reserved_blade()))
 
         self.tear_down_network(self.tenant_id, new_net_dict[const.NET_ID])
 
@@ -503,19 +501,18 @@ class UCSVICTestPlugin(unittest.TestCase):
 
     def tear_down_network_port(self, tenant_id, net_id, port_id):
         blade_intf_details = self._ucs_inventory._get_rsvd_blade_intf_by_port(
-                                                 tenant_id, port_id)
+            tenant_id, port_id)
         self._cisco_ucs_plugin.delete_port(
-                    tenant_id, net_id, port_id, device_ip=self.device_ip,
-                    ucs_inventory=self._ucs_inventory,
-                    chassis_id=self.chassis_id, blade_id=self.blade_id,
-                    blade_intf_distinguished_name=blade_intf_details[\
-                    const.BLADE_INTF_DN],
-                    least_rsvd_blade_dict=self._ucs_inventory.\
-                    _get_least_reserved_blade())
+            tenant_id, net_id, port_id, device_ip=self.device_ip,
+            ucs_inventory=self._ucs_inventory,
+            chassis_id=self.chassis_id, blade_id=self.blade_id,
+            blade_intf_distinguished_name=blade_intf_details[
+                const.BLADE_INTF_DN],
+            least_rsvd_blade_dict=(
+                self._ucs_inventory._get_least_reserved_blade()))
         self.tear_down_network(tenant_id, net_id)
 
     def tear_down_network_port_interface(self, tenant_id, net_id, port_id):
-        self._cisco_ucs_plugin.unplug_interface(
-                                   tenant_id, net_id, port_id,
-                                   device_ip=self.device_ip)
+        self._cisco_ucs_plugin.unplug_interface(tenant_id, net_id, port_id,
+                                                device_ip=self.device_ip)
         self.tear_down_network_port(tenant_id, net_id, port_id)
